// ----------------------------------------------------------------------------
// ILSS_PAR 
// ----------------------------------------------------------------------------
// Parallel Interval Linear System Solver
// ----------------------------------------------------------------------------
// Paralleler Verifizierter Loeser fuer lineare Intervallgleichungssysteme
// ----------------------------------------------------------------------------
// This Version: 
// Copyright (C) 2004-2007 Markus Grimmer
// Based on: 
// Serial Version Copyright (C) 2003 Carlos Holbig and Walter Kraemer
//
// markus.grimmer@math.uni-wuppertal.de
// ----------------------------------------------------------------------------

// This file is part of the Parallel Interval Linear System Solver ILSS_PAR.
// 
// ILSS_PAR is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// ILSS_PAR is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with ILSS_PAR; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------

/**
 * @file ilss_par.hpp
 * 
 * ILSS_PAR Parallel Interval Linear System Solver 
 * Header for central module with all central methods/functions.
 * 
 * Parallel Version Copyright (C) 2004-2007 Markus Grimmer
 *
 * Based on: 
 * Serial Version Copyright (C) 2003 Carlos Holbig and Walter Kraemer
 *
 * Parallel verified solution of interval linear systems
 * using Rump's algorithm.
 */

#ifndef _ILSS_PAR_HPP
#define _ILSS_PAR_HPP

#include <iostream> 
#include <fstream> 
#include <iomanip>       
#include <imatrix.hpp>   
#include <mvi_util.hpp>  
#include "vectoroperations.hpp"  
#include "cxsc_mpicomm_templ.hpp"
#include "matinv_aprx_par.hpp"    // Parallel Matrix inversion
#include "matmul_par.hpp"         // Parallel Matrix multiplication

using namespace cxsc;
using namespace std;

/*
// Only internally available:

void LSS(imatrix& A, ivector& b, ivector& Y,  
         imatrix& MyA, vector<int>& mycolumns, intvector& mycol, 
         bool distribute, int procs, int mypid, int& errc, int& commerrc,
         rmatrix& R1, rmatrix& R2, imatrix& C, int& FLAGS, ofstream& ausg);
*/


extern  void LSS( imatrix&, ivector&, ivector&, 
                  imatrix&, vector<int>&, intvector&, bool,
                  int, int, int&, int&, ofstream& );
extern  void LSS( imatrix&, ivector&, ivector&, 
                  int, int, int&, int&, ofstream& );
extern  void LSS( imatrix&, ivector&, ivector&, int, int, int&, int&, ofstream& );
extern  void LSS( imatrix&, ivector&, ivector&, int&, int&, ofstream& );

#endif
